@@ -21,7 +21,7 @@ if IS_WIN:
     ctypes.windll.kernel32.SetConsoleTextAttribute.restype = ctypes.wintypes.BOOL
 
 def stdoutEncode(data):  # Cross-referenced function
-    raise NotImplementedError
+    return data
 
 class ColorizingStreamHandler(logging.StreamHandler):
     # color names to indices
@@ -158,6 +158,7 @@ class ColorizingStreamHandler(logging.StreamHandler):
             if params and message:
                 match = re.search(r"\A(\s+)", message)
                 prefix = match.group(1) if match else ""
+                message = message[len(prefix):]
 
                 match = re.search(r"\[([A-Z ]+)\]", message)  # log level
                 if match:
@@ -187,14 +188,19 @@ class ColorizingStreamHandler(logging.StreamHandler):
                                 string = match.group(1)
                                 message = message.replace("'%s'" % string, "'%s'" % ''.join((self.csi, str(self.color_map["white"] + 30), 'm', string, self._reset(message))), 1)
                         else:
-                            match = re.search(r" \('(.+)'\)\Z", message)
+                            match = re.search(r"\bresumed: '(.+\.\.\.)", message)
                             if match:
                                 string = match.group(1)
-                                message = message.replace("'%s'" % string, "'%s'" % ''.join((self.csi, str(self.color_map["white"] + 30), 'm', string, self._reset(message))), 1)
+                                message = message.replace("'%s" % string, "'%s" % ''.join((self.csi, str(self.color_map["white"] + 30), 'm', string, self._reset(message))), 1)
                             else:
-                                for match in re.finditer(r"[^\w]'([^']+)'", message):  # single-quoted
+                                match = re.search(r" \('(.+)'\)\Z", message)
+                                if match:
                                     string = match.group(1)
                                     message = message.replace("'%s'" % string, "'%s'" % ''.join((self.csi, str(self.color_map["white"] + 30), 'm', string, self._reset(message))), 1)
+                                else:
+                                    for match in re.finditer(r"[^\w]'([^']+)'", message):  # single-quoted
+                                        string = match.group(1)
+                                        message = message.replace("'%s'" % string, "'%s'" % ''.join((self.csi, str(self.color_map["white"] + 30), 'm', string, self._reset(message))), 1)
                 else:
                     message = ''.join((self.csi, ';'.join(params), 'm', message, self.reset))
 
